@@ -5,6 +5,7 @@
 import asyncio
 import logging.config
 import os
+import signal
 import socket
 import sys
 
@@ -35,6 +36,14 @@ async def create_semaphore(app: web.Application):
     app["dlrepo_publish_semaphore"] = asyncio.Semaphore(max_requests)
 
 
+# --------------------------------------------------------------------------------------
+async def init_fs_cleanup(app: web.Application):
+    repo = app["dlrepo_artifact_repository"]
+    repo.start_cleanup_timer()
+    loop = asyncio.get_running_loop()
+    loop.add_signal_handler(signal.SIGUSR1, repo.schedule_cleanup_all)
+
+
 # --------------------------------------------------------------------------------------
 def main():
     logging.config.dictConfig(
@@ -79,6 +88,7 @@ def main():
     app["dlrepo_artifact_repository"] = repo
 
     app.on_startup.append(create_semaphore)
+    app.on_startup.append(init_fs_cleanup)
 
     views.add_routes(app)
 
