@@ -41,32 +41,12 @@ class FormatDirView(BaseView):
         data = {
             "artifact_format": {
                 "name": fmt.name,
-                "internal": fmt.is_internal(),
                 "dirty": fmt.is_dirty(),
                 "files": list(fmt.get_digests().keys()),
             },
         }
         return web.json_response(data)
 
-    async def put(self):
-        """
-        Change the internal state for a format
-        """
-        version = self.request.match_info.get(
-            "tag", self.request.match_info.get("version")
-        )
-        if "product" in self.request.match_info or version in ("latest", "stable"):
-            raise web.HTTPMethodNotAllowed("PUT", ["GET"])
-        fmt = _get_format(self.repo(), self.request.match_info)
-        try:
-            internal = (await self.json_body())["artifact_format"]["internal"]
-            if not isinstance(internal, bool):
-                raise TypeError()
-        except (TypeError, KeyError) as e:
-            raise web.HTTPBadRequest() from e
-        fmt.set_internal(internal)
-        return web.Response()
-
     async def patch(self):
         """
         Remove the dirty flag from a format.
