@@ -69,6 +69,7 @@ class JobView(JobArchiveView):
         data = {"job": job.get_metadata()}
         data["job"]["internal"] = job.is_internal()
         data["job"]["timestamp"] = job.timestamp
+        data["job"]["digest"] = job.get_digest()
         formats = []
         for f in job.get_formats():
             fmt_url = f.url()
@@ -112,9 +113,11 @@ class JobView(JobArchiveView):
             if internal is not None:
                 job.set_internal(internal)
             if locked is not None:
-                job.set_locked(locked)
+                await job.set_locked(locked)
         except FileNotFoundError as e:
             raise web.HTTPNotFound() from e
+        except OSError as e:
+            raise web.HTTPBadRequest(reason=str(e)) from e
 
         return web.Response()
 
