@@ -191,9 +191,23 @@ class VersionView(BaseView):
 
         formats = []
         for fmt in version.get_formats():
-            if self.access_granted(fmt.url()):
+            fmt_url = fmt.url()
+            if self.access_granted(fmt_url):
                 if html:
-                    formats.append({"name": fmt.name, "internal": fmt.is_internal()})
+                    digests = fmt.get_digests()
+                    deb = rpm = False
+                    if "repodata/repomd.xml" in digests:
+                        rpm = True
+                    elif "Release" in digests:
+                        deb = True
+                    formats.append(
+                        {
+                            "name": fmt.name,
+                            "rpm": rpm,
+                            "deb": deb,
+                            "url": fmt_url,
+                        }
+                    )
                 else:
                     formats.append(fmt.name)
 
