@@ -36,12 +36,20 @@ class BaseView(web.View):
         acls = self.request["dlrepo_user_acls"]
         return auth_backend.access_granted(acls, False, url)
 
-    def response(self, body=None, path=None, status=HTTPStatus.OK, headers=None):
-        if isinstance(body, (dict, list)):
-            return web.json_response(body, status=status, headers=headers)
-        if path is not None:
-            return web.FileResponse(path, status=status, headers=headers)
-        return web.Response(body=body, status=status, headers=headers)
+    X_SENDFILE_HEADER = os.getenv("DLREPO_X_SENDFILE_HEADER", None)
+
+    def file_response(self, path, status=HTTPStatus.OK, headers=None):
+        if self.X_SENDFILE_HEADER:
+            if headers is None:
+                headers = {}
+            headers[self.X_SENDFILE_HEADER] = str(path)
+            if "Content-Type" not in headers:
+                # Force empty Content-Type to prevent aiohttp from adding the
+                # application/octet-stream default value.
+                # The reverse proxy will guess the content type based on the file name.
+                headers["Content-Type"] = ""
+            return web.Response(status=status, headers=headers)
+        return web.FileResponse(path, status=status, headers=headers)
 
     async def json_body(self):
         try:
@@ -52,14 +60,13 @@ class BaseView(web.View):
     async def autoindex(self, fmt, relpath):
         dirs, files = fmt.list_dir(relpath)
         if "index.html" in files:
-            return web.FileResponse(
+            return self.file_response(
                 fmt.get_filepath(os.path.join(relpath, "index.html"))
             )
         data = {
             "artifact_format": {
                 "name": fmt.name,
                 "relpath": relpath.rstrip("/"),
-                "internal": fmt.is_internal(),
                 "dirs": dirs,
                 "files": files,
             },
